<?php

namespace Drupal\global_logout\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\Markup;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\Core\Url;

/**
 * Provides route responses for the Global Logout module.
 */
class GlobalLogoutController extends ControllerBase
{
  /**
   * Returns active login information of the current user
   *
   * @return array
   *   Returns the login information from the customer table
   */
  public function activeLoginInfoPage()
  {
    $user = \Drupal::currentUser();
    $format = \Drupal::config('global_logout.settings')->get('timeformat');
    $uid = $user->id();
    $account = \Drupal\user\Entity\User::load($uid); // pass your uid
    $username = $account->get('name')->value;
    $query = \Drupal::database()->select('globallogout_session_info', 'glsi');
    $query->addField('glsi', 'user_access_information');
    $query->addField('glsi', 'timestamp');
    $query->condition('glsi.uid', $uid);
    $results = $query->execute();
    $rows = [];
    foreach($results as $k => $res) {
      $rows[] = [Markup::create( $k+1), $username, date($format, $res->timestamp), $res->user_access_information];
    }
    $header = [
      'sno' => t('SNO'),
      'username' => t('Username'),
      'date' => t('Date'),
      'uai' => t('User Access Information'),
    ];
    $build['table'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#empty' => t('No content has been found.'),
    ];
    return [
      '#type' => '#markup',
      '#markup' => render($build),
      '#cache' => ['max-age' => 0],
    ];
  }

  public function killSessions(){
    $user = \Drupal::currentUser();
    $uid = $user->id();
    
    $query = \Drupal::database()->delete('sessions');
    $query->condition('uid',$uid);
    $query->execute();
    
    $query = \Drupal::database()->delete('globallogout_session_info');
    $query->condition('uid',$uid);
    $query->execute();
    $url = Url::fromRoute('<front>', [], ['absolute' => TRUE]);
    return new RedirectResponse($url->toString());
  }
}
